package com.luisdigital.bt_micro;

import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.UUID;

import com.luisdigital.lpc800.R;

import android.os.Bundle;
import android.app.Activity;
import android.app.AlertDialog;
import android.bluetooth.*;
import android.content.DialogInterface;
import android.content.Intent;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Toast;
import android.widget.ToggleButton;

/**
 * @author Luis R. Hilario 7/7/2013 (luisdigital.com)
 * 
 * This is my first Android application, used with care, not for critical use.
 *
 */
public class MainActivity extends Activity {

	BluetoothDevice BT_Device;
	BluetoothSocket BT_Socket;
	private String BT_Address = "";
	OutputStream BT_OutputStream = null;
	private BluetoothAdapter BT_Adapter = BluetoothAdapter.getDefaultAdapter();
	final List<String> BTdevices = new ArrayList<String>();
	// Bluetooth Serial ID
	private static final UUID BT_UUID = UUID
			.fromString("00001101-0000-1000-8000-00805f9b34fb");
	private static final int REQUEST_ENABLE_BT = 1;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);


		if (BT_Adapter == null) {
			// Device does not support Bluetooth
			Toast.makeText(getBaseContext(),
					"Device does not support Bluetooth", Toast.LENGTH_SHORT)
					.show();
			finish();
		}

		if (!BT_Adapter.isEnabled()) {
			Intent enableBtIntent = new Intent(
					BluetoothAdapter.ACTION_REQUEST_ENABLE);
			startActivityForResult(enableBtIntent, REQUEST_ENABLE_BT);
		}

	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if ((requestCode == REQUEST_ENABLE_BT)
				&& (resultCode == RESULT_CANCELED)) {
			Toast.makeText(getBaseContext(), "Bluetooth off",
					Toast.LENGTH_SHORT).show();
			finish();
		}
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		// Handle item selection
		switch (item.getItemId()) {
		case R.id.menu_connect:
			BT_Connect();
			return true;
		case R.id.menu_disconnect:
			BT_Address = "";
			onPause();
			return true;
		default:
			return super.onOptionsItemSelected(item);
		}
	}

	public void togleButton1_Click(View view) {

		if (BT_Address == "") {
			Toast.makeText(getBaseContext(), "Disconnected", Toast.LENGTH_SHORT)
			.show();
			return;
		}
		if (((ToggleButton) view).isChecked()) {
			BT_Write("1");
			Toast.makeText(getBaseContext(), "Turn on LED", Toast.LENGTH_SHORT)
			.show();
		} else {
			Toast.makeText(getBaseContext(), "Turn off LED", Toast.LENGTH_SHORT)
			.show();
			BT_Write("0");
		}

	}

	private boolean BT_Connect() {
		if (!BT_Adapter.isEnabled()) {
			Toast.makeText(getBaseContext(), "Bluetooth off",
					Toast.LENGTH_SHORT).show();
			return false;
		}

		final ArrayAdapter<String> adapter = new ArrayAdapter<String>(this,
				android.R.layout.select_dialog_item);
		final Set<BluetoothDevice> pairedDevices = BT_Adapter
				.getBondedDevices();
		// If there are paired devices
		if (pairedDevices.size() > 0) {
			// Loop through paired devices
			for (BluetoothDevice device : pairedDevices) {
				// Add the name and address to an array adapter to show in a
				// ListView
				adapter.add(device.getName() + "\n" + device.getAddress());
			}

			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setAdapter(adapter, new DialogInterface.OnClickListener() {
				public void onClick(DialogInterface dialog, int item) {
					BT_Address = adapter.getItem(item).split("\n")[1];
					onResume();
				}
			});
			builder.create();
			builder.show();
		}

		return true;

	}

	@Override
	public void onResume() {
		super.onResume();

		if (BT_Address == "")
			return;

		BT_Device = BT_Adapter.getRemoteDevice(BT_Address);
		try {
			BT_Socket = BT_Device.createRfcommSocketToServiceRecord(BT_UUID);
		} catch (IOException e1) {
			Print_Error("creating RFComm Connection: " + e1.getMessage());
		}
		try {
			BT_Socket.connect();
		} catch (IOException e1) {
			Print_Error("connecting: " + e1.getMessage());
		}

		try {
			BT_OutputStream = BT_Socket.getOutputStream();
		} catch (IOException e1) {
			Print_Error("creating socket: " + e1.getMessage());
		}

	}

	@Override
	public void onPause() {
		super.onPause();

		if (BT_Address == "")
			return;

		if (BT_OutputStream != null) {
			try {
				BT_OutputStream.flush();
			} catch (IOException e1) {
				Print_Error("flushing output stream: " + e1.getMessage());
			}
		}

		BT_Close();

	}

	private void BT_Close() {
		try {
			BT_Socket.close();
		} catch (IOException e1) {
			Print_Error("closing socket." + e1.getMessage());
		}
	}

	private void BT_Write(String buffer) {

		try {
			BT_OutputStream.write(buffer.getBytes());
		} catch (IOException e1) {

			Print_Error("writing." + e1.getMessage());
		}
	}

	private void Print_Error(String message) {
		Toast.makeText(getBaseContext(), "Error " + message, Toast.LENGTH_LONG)
		.show();
	}
}